﻿using UnityEngine;
using UnityEngine.Networking;
using System.Collections;

public class Quick : NetworkBehaviour {
	//Syncing up the target position.
	[SyncVar]
	public Vector3 targetPosition;

	void Update() {
		//Because the game is now spawning objects from the player-owned objects (spawning from NetworkManager-spawned objects), don't check for 
		//isLocalPlayer, but instead check to see if the clients have authority over the non-player owned objects spawned from the NetworkManager-spawned objects.
		//Wordy, I know...
		if (!this.hasAuthority) {
			return;
		}

		//Simple, "quick," MOBA-style controls. Hence, the class name.
		if (Input.GetMouseButton(0)) {
			CastRay(Input.mousePosition);
		}

		//Have not made any progress in making the clients do all the work in controlling the agent,
		//and letting the server handle transmitting only the target destination point.
		//I'm just happy the code finally works, and happy I started my first step in understanding UNET.
		SetDestination(this.targetPosition);
	}

	void CastRay(Vector3 mousePosition) {
		Ray ray = Camera.main.ScreenPointToRay(mousePosition);
		RaycastHit[] hits = Physics.RaycastAll(ray);
		foreach (RaycastHit hit in hits) {
			if (hit.collider.gameObject.tag.Equals("Floor")) {
				//Call on the client->server method to start the action.
				CmdSetTarget(hit.point);
				break;
			}
		}
	}

	void SetDestination(Vector3 target) {
		NavMeshAgent agent = this.GetComponent<NavMeshAgent>();
		if (agent != null) {
			agent.SetDestination(target);
		}
	}

	[Command]
	public void CmdSetTarget(Vector3 target) {
		//Command call to tell the server to run the following code.
		RpcSetTarget(target);
	}

	//My guess is that this should be a [ClientCallback] instead of [ClientRpc]
	//May require further testing. 
	[ClientRpc]
	public void RpcSetTarget(Vector3 target) {
		//Server tells all clients to run the following codes.
		NavMeshAgent agent = this.GetComponent<NavMeshAgent>();
		if (agent != null) {
			this.targetPosition = target;
		}
	}
}
